#ifndef __FILE_ELEMENTWEIGHTCF_HPP
#define __FILE_ELEMENTWEIGHTCF_HPP

namespace ngfem
{
  class MyElementWeightCF : public CoefficientFunction
  {

	  // create variables for element weights
	  py::array_t<double> weights;
	  py::buffer_info buf;

  public:

	  MyElementWeightCF(py::array_t<double> weights = {})
		  : CoefficientFunction(/*dimension = */ 1)
	  {
		  // store python array with element weights
		  MyElementWeightCF::weights = weights;
		  MyElementWeightCF::buf = weights.request();
	  }

	  // ********************* Define CF Here **********************************
	  virtual double Evaluate(const BaseMappedIntegrationPoint& mip) const override
	  {
		  // get element number in current position
		  int elnr = mip.GetTransformation().GetElementNr();

		  // get poiter to python array
		  double *wptr = (double *) MyElementWeightCF::buf.ptr;

		  // evaluate element weight for a given element
		  double weight = wptr[elnr];

		  return weight;
	  }
	  
  };

  void ExportElementWeightCF(py::module m);
}


#endif //  __FILE_ELEMENTWEIGHTCF_HPP
